/**
 * Theme by BibleTime - https://bibletime.info
 */

#content {
    margin: 10px;
}
#content > table {
    margin: 0;
    padding: 0;
    border-spacing:10px;
    vertical-align:top;
}
#content > table th {
    padding: 0 0 2px 0;
    text-align: center;
    /*font-weight: bold;*/
    font-size: 110%;
    border-bottom: 1px solid #6B6B6B;
}

a {
    text-decoration:none;
    font-weight:normal;
    /*color: #F98100;*/
    color: #FOREGROUND_COLOR#;
    padding:1px;
}

.inline {
    display: inline;
}

/* Settings which apply to all entries in all modules */
.entry {
    padding: 2px;
    /*vertical-align: top;*/
    text-align: justify;
}
#printer .entry {
    font-size: 90%;
    text-align: left;
}
.entry[dir=rtl],#printer .entry[dir=rtl]  {
    text-align: #TEXT_ALIGN#;
}
div.entry, td.entry, td.currententry {
    vertical-align:top;
}

/* Keep the values the same as in .entry (take the border into account!) */
.currententry {
    padding: 2px;
    text-align: justify;
    /*color:white;*/
    /*The background colour of selected text as of kde 3.5.2*/
/*    background-color: #A5A5FF; */
    background-color: #CURRENT_ENTRY#;
}
.currententry[dir=rtl] {
    text-align: #TEXT_ALIGN#;
}
.currententry.inline {
    line-height:1.4em;
}
div.currententry {
}
span.currententry {

}


/*Space between the columns of modules displayed side by side*/
td.entry + td.entry {
    margin-left: 5px;
}

/* Several additional settings for display of modules*/
#bible div.currententry, #bible td.currententry {
    /*border: 1px solid black;*/
    padding: 4px;
}
#bible span.currententry {
}

/*Same for books!*/
#book div.currententry, #book td.currententry {
    border: 1px solid black;
}
#book span.currententry {
}

.entryname {
     font-size:70%;
    padding:0 1px 0 0;
    vertical-align:top;
    /*color: #F98100;*/
    color: black;
    /*font-style: italic;*/
}
.entry[dir=rtl] .entryname, .currententry[dir=rtl] .entryname {
    padding:0 0 0 1px;
    font-size:60%;
    /*vertical-align:top; */
}
.entryname a, #printer .entryname  {
    vertical-align: top;
    font-size: 100%;
    font-weight: bold;
    color: black;
}

#printer .entry  .entry, #printer .entry .sectiontitle , #printer .entry .booktitle {
    padding-top:0.05em;
    margin-left:10px;
}

.footnote {
    vertical-align:super;
    font-weight:bold;
    /*color: #00B7FF;*/ /*This one is kind of blinding on white*/
    /*color: #F98100;*/
    font-size:80%;
    color: black;
}


.footnote:before {
    content: "(";
}

.footnote:after {
    content: ")";
}

.crossreference {
    font-size: 80%;
    color: #CROSSREF_COLOR#
}

.crossreference:before {
    content: "[";
}

.crosreference:after {
    content: "]";
}

.sectiontitle {
    font-weight: bold;
    font-size: large;
}
#printer .sectiontitle {
    font-weight: bold;
    font-size: 100%;
}
* + .sectiontitle {
    margin-top:15px;
}

.booktitle {
    font-weight: bold;
    font-size: large;
    font-variant: small-caps;
}
#printer .booktitle {
    font-weight: bold;
    font-size: large;
    font-variant: small-caps;
}
.foreign {
}
.jesuswords {
    /*color:red;*/
    /*color: #7500AC;*/
    /*color: #F98100;*/
    font-style:italic;
    /*font-weight: bold;*/
    font-size:0.9em;
}
.jesuswords a {
    /* color: red; */
    font-size: 0.9em;
}
a[name="crossref"] {
    font-size: small;
    color: #CROSSREF_COLOR#
}

.quotation {
}
.poetry {
}
.sup {
    vertical-align: super;
}
.sub {
    vertical-align: sub;
}
.right {
    text-align: right;
}
.center {
    text-align: center;
}

.bold {
    font-weight:bold;
}
.illuminated {
}
.italic {
    font-style:italic;
}
.line-through {
    text-decoration: line-through;
}
.normal {
}
.small-caps {
   font-variant: small-caps;
}
.underline {
    text-decoration: underline;
}

.inscription {
}
.mentioned {
}
.name > .geographic {
}
.name > .holiday {
}
.name > .nonhuman {
}
.name > .person {
}
.name > .ritual {
}
.name > .divine {
   font-variant: small-caps;
}

.transchange {
    font-style:italic;
}
.transchange > .added {
}
.transchange > .amplified {
}
.transchange > .changed {
}
.transchange > .deleted {
}
.transchange > .moved {
}
.transchange > .tenseChange {
}

.morphSegmentation {
    border: 1px solid grey;
    margin-top: 1px; /* Don`t let the boxes touch here, between the lines */
    margin-left: -1px; /* But here, for better reading of the text,
                                            this will only occur within a word consisting of several segments.*/
    margin-right: 0px;
}

#infodisplay {
    margin:0;
    padding:0;
}

#infodisplay .footnoteinfo h3, #infodisplay .strongsinfo h3, #infodisplay .morphinfo h3, #infodisplay .translationinfo h3, #infodisplay .crossrefinfo h3, #infodisplay .moduleinfo h3 {
    padding: 2px 0 0 0;
    color: darkGray;
    font-weight: bold;
    border-bottom: 1px solid black;
    margin: 0 0 3px 0;
}

#infodisplay > p { /* We only format the first p child in a special way */
    color: black;
    margin: 0px;
    padding: 0px;
}

/*Required for cross references*/
#infodisplay .entry {
    padding: 2px;
    text-align: justify;
    margin: 0 0 10px 10px;
}
#infodisplay .entry .entry { /*No smaller font size for nested entries*/
    margin: 0px;
}
#infodisplay .entryname {
    padding: 2px;
    margin: 0px;
    text-align: left;
    font-weight: bold;
}

#infodisplay .rangeheading {
    color: black;
    font-weight: bold;
    margin-left: -5px;
}

#printer .rangeheading {
    border-bottom: 1px solid black;
    color: black;
}

.highlightwords {
background-color: #HIGHLIGHT#;
}
.highlightwords2 {
    background-color: #ffaa00;
}
