/**
 * Theme by BibleTime - https://bibletime.info *
 */

#content {
    margin:10px;
}

#content > table {
    margin: 0;
    padding: 0;
    border-spacing:10px;
    vertical-align:top;
}

#content > table th {
    padding: 0 0 2px 0;
    text-align: center;
    font-weight: bold;
    font-size: 110%;
    border-bottom: 1px solid #6B6B6B;
}

a {
    text-decoration:none;
    font-weight:normal;
    color: #FOREGROUND_COLOR#;
    padding:0 2px;
}

.inline {
    display: inline;
}


/* Settings which apply to all entries in all modules */
.entry {
    padding: 3px;
     vertical-align: middle;
    text-align: justify;
}
#printer .entry {
    font-size:90%;
    text-align:left;
}
.entry[dir=rtl] {
    text-align:#TEXT_ALIGN# !important;
}
#printer .entry[dir=rtl] {
    text-align:#TEXT_ALIGN# !important;
}
td.entry, td.currententry {
    vertical-align:top;
}

/* Keep the values the same as in .entry (take the border into account!) */
.currententry {
    padding:3px;
    text-align:justify;
}
.currententry[dir=rtl] {
    text-align:#TEXT_ALIGN# !important;
}
.currententry.inline {
    line-height:1.4em;
}
div.currententry {
}
span.currententry {
    background-color: #CURRENT_ENTRY#;
}


/*Space between the columns of modules displayed side by side*/
td.entry + td.entry {
    margin-left: 5px;
}

/* Several additional settings for display of modules*/
#bible div.currententry, #bible td.currententry {
    border:1px solid black;
    padding:2px;
    background-color: #CURRENT_ENTRY#;
}
#bible span.currententry {
}

/*Same for books!*/
#book div.currententry, #book td.currententry {
    border:1px solid black;
    background-color:#F6FFF7;
}
#book span.currententry {
    background-color:#C8FFB6;
}


.entryname {
    font-size:80%;
    padding:0 2px 0 0;
    vertical-align:super;
}
.entry[dir=rtl] .entryname, .currententry[dir=rtl] .entryname {
    padding: 0 0 0 2px;
    font-size: 80%;
    vertical-align:super;
}
.entryname a, #printer .entryname  {
    vertical-align: middle
}

#printer .entry  .entry, #printer .entry .sectiontitle , #printer .entry .booktitle {
    padding-top: 0.05em;
    margin-left: 10px;
}

.footnote {
    vertical-align:super;
    color: #CROSSREF_COLOR#;
    font-size: 70%;
}
.footnote:before { content:"("; }
.footnote:after { content:")"; }

.crossreference {
    font-size: small;
    /*vertical-align:middle;*/
    color: #CROSSREF_COLOR#;
}

.crossreference a {
    font-size: small;
    /*vertical-align:middle;*/
    color: #CROSSREF_COLOR#;
}

.sectiontitle {
    font-weight: bold;
    font-size: large;
}
#printer .sectiontitle {
    font-weight: bold;
    font-size: 100%;
}
* + .sectiontitle {
    margin-top:15px;
}

.booktitle {
    font-weight: bold;
    font-size: large;
    font-variant: small-caps;
}
#printer .booktitle {
    font-weight: bold;
    font-size: large;
    font-variant: small-caps;
}
.foreign {
}
.jesuswords {
    color:#JESUS_WORDS_COLOR#;
}
.jesuswords a {
    color: #JESUS_WORDS_COLOR#;
}
a[name="crossref"] {
    color: #CROSSREF_COLOR#;
}

.quotation {
}
.poetry {
}
.sup {
    vertical-align: super;
}
.sub {
    vertical-align: sub;
}
.right {
    text-align: right;
}
.center {
    text-align: center;
}

.bold {
    font-weight:bold;
}
.illuminated {
}
.italic {
    font-style:italic;
}
.line-through {
    text-decoration: line-through;
}
.normal {
}
.small-caps {
   font-variant: small-caps;
}
.underline {
    text-decoration: underline;
}

.inscription {
}
.mentioned {
}
.name > .geographic {
}
.name > .holiday {
}
.name > .nonhuman {
}
.name > .person {
}
.name > .ritual {
}
.name > .divine {
   font-variant: small-caps;
}

.transchange {
    font-style:italic;
}
.transchange > .added {
}
.transchange > .amplified {
}
.transchange > .changed {
}
.transchange > .deleted {
}
.transchange > .moved {
}
.transchange > .tenseChange {
}

.morphSegmentation {
    border: 1px solid gray;
    margin-top: 1px; /* Don`t let the boxes touch here, between the lines */
    margin-left: -1px; /* But here, for better reading of the text,
                                            this will only occur within a word consisting of several segments.*/
    margin-right: 0px;
}

#infodisplay {
    margin:0;
    padding:0;
}

#infodisplay .footnoteinfo h3, #infodisplay .strongsinfo h3, #infodisplay .morphinfo h3, #infodisplay .translationinfo h3, #infodisplay .crossrefinfo h3, #infodisplay .moduleinfo h3 {
    padding:4px 4px 2px 0;
    color:darkGray;
    font-weight:bold;
    border-bottom:1px solid gray;
    text-align:left !important;
}

#infodisplay > p, #infodisplay  * > p { /* We only format the first p child in a special way */
    text-align:justify;
    margin:0px;
    padding:0px;
}

/*Required for cross references*/
#infodisplay .entry {
    padding:2px;
    text-align:justify;
    margin-bottom:10px;
    margin-left:15px;
}
#infodisplay .entry .entry { /*No smaller font size for nested entries*/
    margin:0px;
}
#infodisplay .entryname {
    padding:2px;
    margin:0px;
    text-align:left;
    font-weight:bold;
}

#infodisplay .rangeheading {
    color:black;
    font-weight:bold;
    margin-left:-10px;
}

#printer .rangeheading {
    border-bottom:1px solid black;
    color:black;
}

.highlightwords {
    background-color: #HIGHLIGHT#;
}
.highlightwords2 {
    background-color: #ffaa00;
}
